@@ -19,23 +19,32 @@ const initSaveReportScope = function ($scope, commonHelper) {
     $scope.is_admin = commonHelper.checkifAdmin($scope.roles);
 };
 
+const groupConditionsByCategory = ($scope, savedConditions, commonHelper) => {
+    $scope.savedConditions = {}
+
+    if (!Array.isArray(savedConditions)) {
+        savedConditions = Object.values(savedConditions).flat();
+    }
+    savedConditions.forEach(item => {
+        if (!$scope.savedConditions[item.category]) {
+            $scope.savedConditions[item.category] = [];
+        }
+        $scope.savedConditions[item.category].push(item);
+    })
+    $scope.savedConditions = commonHelper.sortObjectByKey($scope.savedConditions);
+
+}
 const loadConditions = function ($scope, rulesService, commonHelper) {
     if ($scope.conditionIds.length > 0) {
         rulesService.getrules($scope.conditionIds).then(data => {
-            data.data.forEach(item => {
-                if ($scope.savedConditions[item.category] == undefined) {
-                    $scope.savedConditions[item.category] = [];
-                }
-                $scope.savedConditions[item.category].push(item);
-            });
-            $scope.savedConditions = commonHelper.sortObjectByKey($scope.savedConditions);
+            groupConditionsByCategory($scope, data.data, commonHelper);
         });
     }
 };
 
 BaseController.$inject = ['$scope'];
 const complianceMainController = BaseController.extend({
-    init: function ($scope, $location, rulesService, modalWindowService, commonHelper, reportService, paginationService, $routeParams, complianceHelper) {
+    init: function ($scope, $location, rulesService, modalWindowService, commonHelper, reportService, paginationService, $routeParams, complianceHelper, globalHelper) {
         let self = this;
         this._super($scope);
         this.$location = $location;
@@ -43,6 +52,7 @@ const complianceMainController = BaseController.extend({
         this.rulesService = rulesService;
         this.reportService = reportService;
         this.commonHelper = commonHelper;
+        this.globalHelper = globalHelper;
         this.$scope.modalWindow = modalWindowService;
         this.$scope.complianceHelper = complianceHelper;
         this.$scope.paginator = paginationService;
@@ -180,12 +190,12 @@ const complianceMainController = BaseController.extend({
     },
 
     getUserName: function (row) {
-        return this.commonHelper.getUserName(row.meta_data.source, row.username)
+        return this.globalHelper.getUserName(row.meta_data.source, row.username)
     }
 
 });
 
-complianceMainController.$inject = ['$scope', '$location', 'rulesService', 'modalWindowService', 'commonHelper', 'reportService', 'paginationService', '$routeParams', 'complianceHelper'];
+complianceMainController.$inject = ['$scope', '$location', 'rulesService', 'modalWindowService', 'commonHelper', 'reportService', 'paginationService', '$routeParams', 'complianceHelper', 'globalHelper'];
 
 const complianceCreateEditController = BaseController.extend({
 
@@ -446,6 +456,9 @@ const complianceResultController = BaseController.extend({
         this.$scope.showEnvironmentFilterButtons = true;
         this.timeout = null;
 
+        this.$scope.sortByProperty = '';
+        this.$scope.sortMode = 'NOR';
+
         this.$scope.stats = {
             severity: {
                 high: {pass: 0, fail: 0},
@@ -463,11 +476,40 @@ const complianceResultController = BaseController.extend({
         this.reportService.getTotalHostsCount(this.getInclExclParams()).then(count => this.$scope.total = count);
         this.runReport();
     },
-
+    sortConditionBy: function (sortProperty) {
+        let self = this;
+        const shiftMode = () => {
+            const modes = ['NOR', 'ASC', 'DSC'];
+            const currentModeIndex = modes.findIndex(el => el === self.$scope.sortMode);
+            self.$scope.sortMode = (sortProperty === self.$scope.sortByProperty) ? modes[(currentModeIndex + 1) % modes.length] : modes[1];
+        }
+        shiftMode();
+        if (self.$scope.sortMode === 'NOR') {
+            groupConditionsByCategory(self.$scope, self.$scope.savedConditions, self.commonHelper)
+            return;
+        }
+        function sortByProperty(array, prop, reverse) {
+            const severityOrder = {"high": 3, "medium": 2, "low": 1};
+                return array.sort((a, b) => {
+                    a = prop === 'severity' ? severityOrder[a[prop]]: a[prop];
+                    b = prop === 'severity' ?  severityOrder[b[prop]]: b[prop];
+                    if (a < b) {
+                        return reverse ? 1 : -1;
+                    } else if (a > b) {
+                        return reverse ? -1 : 1;
+                    }
+                    return 0;
+                });
+        }
+        self.$scope.sortByProperty = sortProperty;
+        const newConditions = Object.values(self.$scope.savedConditions).flat();
+        self.$scope.savedConditions = {All: sortByProperty(newConditions, self.$scope.sortByProperty, self.$scope.sortMode === 'DSC')};
+    },
     defineScope: function () {
         this.$scope.loadStatistics = this.loadStatistics.bind(this);
         this.$scope.viewHosts = this.viewHosts.bind(this);
         this.$scope.saveReport = this.saveReport.bind(this);
+        this.$scope.sortConditionBy = this.sortConditionBy.bind(this);
     },
 
     defineListeners: function () {
@@ -493,7 +535,7 @@ const complianceResultController = BaseController.extend({
             };
 
             // change x and y axis text color for category bar chart
-            let categoryOptions = $('#category_failures').highcharts().userOptions;
+            let categoryOptions = angular.copy($('#category_failures').highcharts().userOptions);
             categoryOptions.xAxis.labels = categoryOptions.yAxis.labels = {style: {color: '#333333'}};
             categoryOptions.xAxis = [categoryOptions.xAxis];
             categoryOptions.yAxis = [categoryOptions.yAxis];
@@ -515,7 +557,7 @@ const complianceResultController = BaseController.extend({
             self.buildCsvArray();
         }, true);
 
-        $('body').on('DARK_THEME_CHANGED', function() {
+        $('body').on('DARK_THEME_CHANGED', function () {
             self.loadCharts();
             self.$scope.$digest();
         });
@@ -586,7 +628,7 @@ const complianceResultController = BaseController.extend({
 
     },
 
-    loadCharts: function() {
+    loadCharts: function () {
         this.$scope.overallConfig = this.complianceHelper.overallConfig(this.$scope.stats);
         this.$scope.categoriesConfig = this.complianceHelper.categoriesConfig(this.$scope.stats);
     },
@@ -667,7 +709,7 @@ const complianceResultController = BaseController.extend({
         let params = this.getInclExclParams();
         let ids = [];
         stats.totalChecks = self.$scope.conditionIds.length;
-
+        
         const ruleIds = Object.keys(self.$scope.savedConditions).reduce((acc, category) => {
             acc = [...acc, ...self.$scope.savedConditions[category].map(item => item.id)];
             return acc;
